<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package verscontabilidade
 */

/**
 * Adds custom classes to the array of body classes.
 *
 * @param array $classes Classes for the body element.
 * @return array
 */
function verscontabilidade_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	if (is_blog()) {
		$classes[] = 'blog';
	}

	return $classes;
}
add_filter( 'body_class', 'verscontabilidade_body_classes' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function verscontabilidade_pingback_header() {
	if ( is_singular() && pings_open() ) {
		echo '<link rel="pingback" href="', esc_url( get_bloginfo( 'pingback_url' ) ), '">';
	}
}
add_action( 'wp_head', 'verscontabilidade_pingback_header' );

function verscontabilidade_form_input($field){
	$required = $field['required'] ? 'required' : '';
	$placeholder = $field['placeholder'] ? $field['placeholder'] : $field['name'];

	$input = '<div class="input-wrapper">';

	switch ($field['acf_fc_layout']) {	
		case 'dropdown':
			$options = array('' => $placeholder);

			foreach ($field['options'] as $option) {
				$options[$option['value']] = $option['value'];
			}

			$input .= form_dropdown('form_data['.$field['name'].']', $options, '', $required);
		break;

		default:
			$input .= '<input type="'.$field['acf_fc_layout'].'" name="form_data['.$field['name'].']" '.$required.' placeholder="'.$placeholder.'" />';
		break;
	}

	$input .= '</div>';

	return $input;
}

function verscontabilidade_get_search_form($form){
	return '<form role="search" method="get" class="search-form" action="' . esc_url( home_url( '/' ) ) . '">
            <label>
                    <span class="screen-reader-text">' . _x( 'Search for:', 'label' ) . '</span>
                    <input type="search" class="search-field" placeholder="' . esc_attr_x( 'Search &hellip;', 'placeholder' ) . '" value="' . get_search_query() . '" name="s" />
            </label>
            <button class="search-submit" value="'. esc_attr_x( 'Search', 'submit button' ) .'"><div class="glyphicon glyphicon-search"></div></button>
    </form>';
}

add_filter( 'get_search_form', 'verscontabilidade_get_search_form' );



if (!function_exists('is_blog')) {
    function is_blog(){
        return is_home() || is_search() || (is_archive() && get_post_type() == 'post') || (is_single() && get_post_type() == 'post');
    }
}
